translate.storage.mozilla_lang

Package translate :: Package storage :: Module mozilla_lang |
[hide private]
[frames] | no frames]

# Module mozilla_lang

source code

A class to manage Mozilla .lang files.

Classes | [hide private]
| LangUnit This is just a normal unit with a weird string output
| LangStore We extend TxtFile, since that has a lot of useful stuff for encoding

Variables | [hide private]
| __package__ = ``'``translate.storage``'``

Imports: base, txt